Geoserver REST API Access Control List Manager
Geoserver REST API Access Control List Manager
Object of R6Class with methods for managing GeoServer
Access Control List (ACL) operations.
R6Class object.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
geosapi::GSManager -> GSAccessControlListManager
Inherited methods
geosapi::GSManager$ERROR()geosapi::GSManager$INFO()geosapi::GSManager$WARN()geosapi::GSManager$connect()geosapi::GSManager$getClassName()geosapi::GSManager$getCoverageStoreManager()geosapi::GSManager$getDataStoreManager()geosapi::GSManager$getNamespaceManager()geosapi::GSManager$getServiceManager()geosapi::GSManager$getStyleManager()geosapi::GSManager$getSystemStatus()geosapi::GSManager$getUrl()geosapi::GSManager$getWorkspaceManager()geosapi::GSManager$initialize()geosapi::GSManager$logger()geosapi::GSManager$monitor()geosapi::GSManager$reload()
setCatalogMode()Set the catalog mode
GSAccessControlListManager$setCatalogMode(
mode = c("HIDE", "MIXED", "CHALLENGE")
)modemode
TRUE if set, FALSE otherwise
getCatalogMode()Get the catalog mode
GSAccessControlListManager$getCatalogMode()the mode either HIDE, MIXED or CHALLENGE
getRules()Get rules
GSAccessControlListManager$getRules(domain = c("layers", "services", "rest"))domainthe access control domain
the list of rules for a given domain
getLayerRules()Method to get the list of 'layers' rules
GSAccessControlListManager$getLayerRules()the list of 'layers' rules
getServiceRules()Method to get the list of 'services' rules
GSAccessControlListManager$getServiceRules()the list of 'services' rules
getRestRules()Method to get the list of 'rest' rules
GSAccessControlListManager$getRestRules()the list of 'rest' rules
getRule()Method to get a rule by resource
GSAccessControlListManager$getRule(
domain = c("layers", "services", "rest"),
resource
)domainthe access control domain
resourceresource
an object of class GSRule or NULL if no rule is found
getLayerRule()Method to get a 'layers' rule
GSAccessControlListManager$getLayerRule(resource)resourceresource
an object of class GSLayerRule or NULL if no rule is found
getServiceRule()Method to get a 'services' rule
GSAccessControlListManager$getServiceRule(resource)resourceresource
an object of class GSServiceRule or NULL if no rule is found
getRestRule()Method to get a 'rest' rule
GSAccessControlListManager$getRestRule(resource)resourceresource
an object of class GSRestRule or NULL if no rule is found
addRule()Generic method to add an access control rule
GSAccessControlListManager$addRule(rule, position = c("first", "last"))ruleobject of class GSRule
positionposition with the list of rules, either "first" or "last". The position is especially true to capture to the order of priority. For priority, put 'first'.
TRUE if added, FALSE otherwise
addLayerRule()Adds an access control layer rule
GSAccessControlListManager$addLayerRule(
ws = NULL,
lyr = "*",
permission = c("r", "w", "a"),
roles
)wsthe resource workspace. Default is NULL
lyrthe target layer to which the access control should be added
permissionthe rule permission, either r (read), w (write) or a (administer)
rolesone or more roles to add for the rule
TRUE if added, FALSE otherwise
addServiceRule()Adds an access control service rule
GSAccessControlListManager$addServiceRule(
service,
method,
permission = c("r", "w", "a"),
roles
)serviceservice subject to the access control rule, eg. 'wfs'
methodservice method subject to the access control rule, eg. 'GetFeature'
permissionthe rule permission, either r (read), w (write) or a (administer)
rolesone or more roles to add for the rule
TRUE if added, FALSE otherwise
addRestRule()Adds an access control rest rule
GSAccessControlListManager$addRestRule(pattern = "/**", methods, roles)patterna URL Ant pattern, only applicable for domain rest. Default is /**
methodsHTTP method(s)
rolesone or more roles to add for the rule
TRUE if added, FALSE otherwise
modifyRule()Generic method to modify an access control rule
GSAccessControlListManager$modifyRule(rule, position = c("first", "last"))ruleobject of class GSRule
positionposition with the list of rules, either "first" or "last". The position is especially true to capture to the order of priority. For priority, put 'first'.
TRUE if modified, FALSE otherwise
deleteRule()Generic method to delete an access control rule
GSAccessControlListManager$deleteRule(rule)ruleobject of class GSRule
TRUE if deleted, FALSE otherwise
clone()The objects of this class are cloneable with this method.
GSAccessControlListManager$clone(deep = FALSE)deepWhether to make a deep clone.
if (FALSE) {
GSAccessControlListManager$new("http://localhost:8080/geoserver", "admin", "geoserver")
}
Run the code above in your browser using DataLab