This class models a GeoServer access control list layer rule
Object of R6Class for modelling a GeoServer access control list layer rule
R6Class object.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
geosapi::GSRESTResource -> geosapi::GSRule -> GSLayerRule
rolesone or more roles
new()Initializes a GSLayerRule
GSLayerRule$new(
xml = NULL,
ws = NULL,
lyr,
permission = c("r", "w", "a"),
roles
)xmlan object of class xml_node-class
wsthe resource workspace. Default is NULL
lyrthe target layer to which the access control should be added
permissionthe rule permission, either r (read), w (write) or a (administer)
rolesone or more roles to add for the rule
clone()The objects of this class are cloneable with this method.
GSLayerRule$clone(deep = FALSE)deepWhether to make a deep clone.
Geoserver REST API Access Control List Layer Rule