Learn R Programming

geosapi (version 0.8-1)

GSRestRule: A GeoServer access control list service rule

Description

This class models a GeoServer access control list service rule

Arguments

Value

Object of R6Class for modelling a GeoServer access control list service rule

Format

R6Class object.

Author

Emmanuel Blondel <emmanuel.blondel1@gmail.com>

Super classes

geosapi::GSRESTResource -> geosapi::GSRule -> GSRestRule

Public fields

roles

one or more roles

Methods

Inherited methods


Method new()

Initializes a GSLayerRule

Usage

GSRestRule$new(xml = NULL, pattern = "/**", methods, roles)

Arguments

xml

an object of class xml_node-class

pattern

a URL Ant pattern, only applicable for domain rest. Default is /**

methods

HTTP method(s)

roles

one or more roles to add for the rule


Method clone()

The objects of this class are cloneable with this method.

Usage

GSRestRule$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

Geoserver REST API Access Control List REST Rule