This class models a GeoServer access control list service rule
Object of R6Class for modelling a GeoServer access control list service rule
R6Class object.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
geosapi::GSRESTResource -> geosapi::GSRule -> GSServiceRule
rolesone or more roles
new()Initializes a GSLayerRule
GSServiceRule$new(
xml = NULL,
service,
method,
permission = c("r", "w", "a"),
roles
)xmlan object of class xml_node-class
serviceservice subject to the access control rule, eg. 'wfs'
methodservice method subject to the access control rule, eg. 'GetFeature'
permissionthe rule permission, either r (read), w (write) or a (administer)
rolesone or more roles to add for the rule
clone()The objects of this class are cloneable with this method.
GSServiceRule$clone(deep = FALSE)deepWhether to make a deep clone.
Geoserver REST API Access Control List Service Rule