This class models a GeoServer access control list service rule
Object of R6Class for modelling a GeoServer access control list service rule
R6Class object.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
geosapi::GSRESTResource -> geosapi::GSRule -> GSRestRule
rolesone or more roles
new()Initializes a GSLayerRule
GSRestRule$new(xml = NULL, pattern = "/**", methods, roles)xmlan object of class xml_node-class
patterna URL Ant pattern, only applicable for domain rest. Default is /**
methodsHTTP method(s)
rolesone or more roles to add for the rule
clone()The objects of this class are cloneable with this method.
GSRestRule$clone(deep = FALSE)deepWhether to make a deep clone.
Geoserver REST API Access Control List REST Rule